==> seplib-6.3.9.tar.gz: seplib-6.3.9/seplib_base/lib/python/corelibs/par.py <==
import re
import string
import pwd
import sys
import os
import socket
import time
from math import *


class sep_pars:
  def __init__(self,file=None,name=None,seppar=None):
     self.params={}
     self.added={}
     self.iamstring={}
     self.qbase="A1b2C"
     if file != None: self.init_file(file)
     elif seppar != None:  
       if name !=None: self.init_seppar(seppar,name)
       else: 
         print "Must provide the name when initializing a sep_par"
         sys.exit(-1) 
     elif name !=None: self.params["myname"]=name
     else:
       print "Must provide name or file when creating "
       sys.exit(-1) 
       

  def init_seppar(self,seppar,name):
    for par,val in seppar.params.items():
      self.params[par]=val
    for par,val in seppar.added.items():
      self.added[par]=val
    for par,val in seppar.iamstring.items():
      self.iamstring[par]=val
    self.params['myfile']=name
    self.mylines = seppar.mylines

  def init_file(self,file):
    try: f = open (file)   #OPEN THE FILE
    except:
      print 'Trouble opening file for reading', file
      sys.exit(-1) 
    self.mylines = f.readlines()  #READ IN THE ENTIRE FILE TO LINES
    f.close()
    self.build_database(file)
    self.params["myname"]=file

  def build_database(self,file):
    try: f = open (file)   #OPEN THE FILE
    except:
      print 'Trouble opening file for reading', file
      sys.exit(-1) 
    lines = f.readlines()  #READ IN THE ENTIRE FILE TO LINES
    self.parS=re.compile('(\S+)=(\S+)')
    self.comS=re.compile('A1b2C(\S+)')

    for line in lines:
      quotes,line=self.split_line(line) 
      parts=line.split()
      self.add_args(parts)
    f.close()  

  def add_args(self,parts):
    for part in parts:
      param=self.parS.search(part)
      if param:  #we have a parameter
        c=self.comS.search(param.group(2)) #do we have a quote?
        if c: 
          val=quotes[c.group(1)]
          self.iamstring[param.group(1)]=1
        else: val=param.group(2)
        if param.group(1) == "par":
          self.build_database(val) 
        else: 
          self.params[param.group(1)]=val

  def split_line(self,line):
    quotes=[]
    c1=0
    q1,q2,c1,iend=self.find_q_c(line)
    while q1 <iend and q2 < iend:
      if  c1 < q2 and q1 < c1: # we have a comment
        return quotes,line
      if  q1 < q2 and q1 < c1: #possible quoted string "
        iend=line.find('"')
        line,quotes,c1=self.str_replace(line,quotes,q1,iend,c1)
      if  q2 < q1 and q2 < c1: #possible quoted string '
        iend=line.find('"')
        line,quotes,c1=self.str_replace(line,quotes,q2,iend,c1)
      q1,q2,c1,iend=self.find_q_c(line)
    return quotes,line
 
  def str_replace(self,line,quotes,ibeg,iend,qnum):
     if iend==-1: #open quote
       return line[0:ibeg-1],quotes,qnum
     quotes.append(line[ibeg+1:iend-1])
     k=qnum+1
     return line[0:ibeg-1]+self.qbase+qnum+line[iend+1:],quotes,k
          
  def find_q_c(self,line):
     iend=len(line)
     q1=line.find('"')
     q2=line.find("'")
     c1=line.find('#')
     if q1 == -1: q1=iend+1
     if q2 == -1: q2=iend+1
     if c1 == -1: c1=iend+1
     return q1,q2,c1,iend

  def par(self,p,default=None):
    if self.params.has_key(p):
      if self.iamstring.has_key(p): return self.params[p],1
      return self.not_string(self.params[p])
    elif default != None:
      if default[0]=='"' or default[0]=="'": return default,1
      return self.not_string(self.params[p])
    else:
       return None,0

  def write_pars(self,file):
    try: f = open (file,"w")   #OPEN THE FILE
    except:
      print 'Trouble opening file for writing:', file
      sys.exit(-1) 
    for par,item in self.params.items():
      if self.iamstring.has_key(par):
        f.write("\t"+par+'="'+item+'"\n')
      else:
        f.write("\t"+par+'='+str(item)+"\n")
    f.close()

  def write_new_pars(self,file):
    try: f = open (file,"w")   #OPEN THE FILE
    except:
      print 'Trouble opening file writing:', file
      sys.exit(-1) 
    for line in self.mylines:
      f.write(line)
    f.write(sys.argv[0]+":   "+pwd.getpwuid(os.getuid())[0])
    f.write("@"+socket.gethostname()+" "+
    time.strftime("%a %b %d %H:%M:%S %Y",time.localtime(int(time.time())))+"\n")

    host=socket.gethostname()
    for par,item in self.added.items():
      if self.iamstring.has_key(par):
        f.write("\t"+par+'="'+str(item)+'"\n')
      else:
        f.write("\t"+par+'='+str(item)+"\n")
    f.close()

  def add_param(self,par,val,type="str"):
    if re.search("\s+",str(val)): self.iamstring[par]=1
    if type == "int":
      self.params[par]=int(val)
      self.added[par]=int(val)
    else:
      self.params[par]=val
      self.added[par]=val
     
  def not_string(self,cc):
     if re.search(",",str(cc)):
       vals=cc.split(",")
       return vals,len(vals)
     else:
       return cc,1

==> seplib-6.3.12.tar.gz: seplib-6.3.12/seplib_base/lib/python/corelibs/par.py <==
import re
import string
import pwd
import sys
import os
import time
import SEP.util
from math import *


class sep_pars:
  def __init__(self,file=None,name=None,seppar=None):
     self.params={}
     self.added={}
     self.iamstring={}
     self.qbase="A1b2C"
     self.name="None"
     self.mylines=[]
     if file != None: self.init_file(file)
     elif seppar != None:  
       if name !=None: self.init_seppar(seppar,name)
       else: 
         raise SEP.util.err,"Must provide the name when initializing a sep_par"
     elif name !=None: self.name=name
     else:
       raise SEP.util.err, "Must provide name or file when creating "
       

  def init_seppar(self,seppar,name):
    for par,val in seppar.params.items():
      self.params[par]=val
    for par,val in seppar.added.items():
      self.added[par]=val
    for par,val in seppar.iamstring.items():
      self.iamstring[par]=val
    self.name=name
    self.mylines = seppar.mylines

  def init_file(self,file):
    try: f = open (file)   #OPEN THE FILE
    except:
      raise SEP.util.err, 'Trouble opening file for reading', file
    self.mylines = f.readlines()  #READ IN THE ENTIRE FILE TO LINES
    f.close()
    self.build_database(file)
    self.name=file

  def build_database(self,file):
    try: f = open (file)   #OPEN THE FILE
    except:
      raise SEP.util.err, 'Trouble opening file for reading', file
    lines = f.readlines()  #READ IN THE ENTIRE FILE TO LINES
    parq1=re.compile('(\S+)="(\S+)"')
    parq2=re.compile("(\S+)='(\S+)'")
    parS=re.compile('(\S+)=(\S+)')
    for line in lines:
      args=line.split()
      comment=0
      for arg in args:
        if arg[0]=="#": comment=1
        if comment!=1:
          q=0
          res=parq1.search(arg)
          if  res: q=1
          else:
            res=parq2.search(arg)
            if res: q=1
            else:
              res=parS.search(arg)
        if res:
          self.params[res.group(1)]=res.group(2)
          if q==1: self.iamstring[res.group(1)]=1
    f.close()  

  def par(self,p,default=None):
    if self.params.has_key(p):
      if self.iamstring.has_key(p): return self.params[p],1
      return self.not_string(self.params[p])
    elif default != None:
      if default[0]=='"' or default[0]=="'": return default,1
      return self.not_string(self.params[p])
    else:
       return None,0

  def write_pars(self,file):
    try: f = open (file,"w")   #OPEN THE FILE
    except:
      raise SEP.util.err, 'Trouble opening file for writing:', file
    for par,item in self.params.items():
      if self.iamstring.has_key(par):
        f.write("\t"+par+'="'+str(item)+'"\n')
      else:
        f.write("\t"+par+'='+str(item)+"\n")
    f.close()

  def write_new_pars(self,file):
    try: f = open (file,"w")   #OPEN THE FILE
    except:
      raise SEP.util.err, 'Trouble opening file writing:'+ file
    for line in self.mylines:
      f.write(line)
    f.write(sys.argv[0]+":   "+pwd.getpwuid(os.getuid())[0])
    f.write("@"+os.uname()[1]+" "+
    time.strftime("%a %b %d %H:%M:%S %Y",time.localtime(int(time.time())))+"\n")

    host=os.uname()[1]
    for par,item in self.added.items():
      if self.iamstring.has_key(par):
        f.write("\t"+par+'="'+str(item)+'"\n')
      else:
        f.write("\t"+par+'='+str(item)+"\n")
    f.close()

  def add_param(self,par,val,type="str"):
    if re.search("\s+",str(val)): self.iamstring[par]=1
    if type == "int":
      self.params[par]=int(val)
      self.added[par]=int(val)
    else:
      self.params[par]=val
      self.added[par]=val
     
  def not_string(self,cc):
     if re.search(",",str(cc)):
       vals=cc.split(",")
       return vals,len(vals)
     else:
       return cc,1
